==> apache-cloudstack-4.18.2.1-src.tar.bz2: apache-cloudstack-4.18.2.1-src/plugins/integrations/kubernetes-service/src/main/java/com/cloud/kubernetes/cluster/dao/KubernetesClusterDao.java <==
// Licensed to the Apache Software Foundation (ASF) under one
// or more contributor license agreements.  See the NOTICE file
// distributed with this work for additional information
// regarding copyright ownership.  The ASF licenses this file
// to you under the Apache License, Version 2.0 (the
// "License"); you may not use this file except in compliance
// with the License.  You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing,
// software distributed under the License is distributed on an
// "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
// KIND, either express or implied.  See the License for the
// specific language governing permissions and limitations
// under the License.
package com.cloud.kubernetes.cluster.dao;

import java.util.List;

import com.cloud.kubernetes.cluster.KubernetesCluster;
import com.cloud.kubernetes.cluster.KubernetesClusterVO;
import com.cloud.utils.db.GenericDao;
import com.cloud.utils.fsm.StateDao;

public interface KubernetesClusterDao extends GenericDao<KubernetesClusterVO, Long>,
        StateDao<KubernetesCluster.State, KubernetesCluster.Event, KubernetesCluster> {

    List<KubernetesClusterVO> listByAccount(long accountId);
    List<KubernetesClusterVO> findKubernetesClustersToGarbageCollect();
    List<KubernetesClusterVO> findKubernetesClustersInState(KubernetesCluster.State state);
    List<KubernetesClusterVO> listByNetworkId(long networkId);
    List<KubernetesClusterVO> listAllByKubernetesVersion(long kubernetesVersionId);
}

==> apache-cloudstack-4.20.0.0-src.tar.bz2: apache-cloudstack-4.20.0.0-src/plugins/integrations/kubernetes-service/src/main/java/com/cloud/kubernetes/cluster/dao/KubernetesClusterDao.java <==
// Licensed to the Apache Software Foundation (ASF) under one
// or more contributor license agreements.  See the NOTICE file
// distributed with this work for additional information
// regarding copyright ownership.  The ASF licenses this file
// to you under the Apache License, Version 2.0 (the
// "License"); you may not use this file except in compliance
// with the License.  You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing,
// software distributed under the License is distributed on an
// "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
// KIND, either express or implied.  See the License for the
// specific language governing permissions and limitations
// under the License.
package com.cloud.kubernetes.cluster.dao;

import java.util.List;

import com.cloud.kubernetes.cluster.KubernetesCluster;
import com.cloud.kubernetes.cluster.KubernetesClusterVO;
import com.cloud.utils.db.GenericDao;
import com.cloud.utils.fsm.StateDao;

public interface KubernetesClusterDao extends GenericDao<KubernetesClusterVO, Long>,
        StateDao<KubernetesCluster.State, KubernetesCluster.Event, KubernetesCluster> {

    List<KubernetesClusterVO> listByAccount(long accountId);
    List<KubernetesClusterVO> findKubernetesClustersToGarbageCollect();
    List<KubernetesClusterVO> findManagedKubernetesClustersInState(KubernetesCluster.State state);
    List<KubernetesClusterVO> listByNetworkId(long networkId);
    List<KubernetesClusterVO> listAllByKubernetesVersion(long kubernetesVersionId);
}
